Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2304)

Unified Diff: chrome/browser/sync/test/integration/sync_app_list_helper.h

Issue 1851243002: [Sync] Eliminate verifier profile from sync_integration_tests (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: do not remove AwaitQuiescence() Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/sync_app_list_helper.h
diff --git a/chrome/browser/sync/test/integration/sync_app_list_helper.h b/chrome/browser/sync/test/integration/sync_app_list_helper.h
index cd788b25b023bdb9b0bac929b471cba24c9ac2dd..90ec898f1b140242836e2b933d99032ce8bbf2fc 100644
--- a/chrome/browser/sync/test/integration/sync_app_list_helper.h
+++ b/chrome/browser/sync/test/integration/sync_app_list_helper.h
@@ -29,9 +29,8 @@ class SyncAppListHelper {
// internal data structures.
void SetupIfNecessary(SyncTest* test);
- // Returns true iff all existing profiles have the same app list entries
- // as the verifier.
- bool AllProfilesHaveSameAppListAsVerifier();
+ // Returns true iff all existing profiles have the same app list entries.
+ bool AllProfilesHaveSameAppList();
// Moves an app in |profile|.
void MoveApp(Profile* profile, size_t from, size_t to);
@@ -46,9 +45,6 @@ class SyncAppListHelper {
size_t index_in_folder,
const std::string& folder_id);
- // Copies ordinals for item matching |id| from |profile1| to test_->verifier.
- void CopyOrdinalsToVerifier(Profile* profile1, const std::string& id);
-
// Helper function for debugging, used to log the app lists on test failures.
void PrintAppList(Profile* profile);
@@ -58,9 +54,9 @@ class SyncAppListHelper {
SyncAppListHelper();
~SyncAppListHelper();
// Returns true iff |profile| has the same app list as |test_|->verifier()
// and the app list entries all have the same state.
- bool AppListMatchesVerifier(Profile* profile);
+ bool AppListMatch(Profile* profile1, Profile* profile2);
// Helper function for debugging, logs info for an item, including the
// contents of any folder items.
@@ -58,9 +54,9 @@ class SyncAppListHelper {
SyncAppListHelper();
~SyncAppListHelper();
- // Returns true iff |profile| has the same app list as |test_|->verifier()
+ // Returns true iff |profile1| has the same app list as |profile2|
// and the app list entries all have the same state.

Powered by Google App Engine
This is Rietveld 408576698